#include-once

#include "constantGraphObjet2010.au3"
#include "ConstantsOfficeMso2013.au3"

; #FUNCTION# ====================================================================================================================
; Name ..........: graphiqueExcel
; Description ...: Automatise le tra de graphique Excel (test sur Excel 2007 et Autoit v3.3.12.0)
; Syntax ........: graphiqueExcel($oAppl, $SheetData, $Data, $SourceData, $ChartType, $Tracerpar[, $FormatGraphic = ""[,
;                  $FormatSave = ""[, $PathSave = ""]]])
; Parameters ....: $oAppl               - object retourn par _Excel_Open()
;                  $SheetData           - nom de la feuille Excel
;                  $Data                - donnes du graphique, peut tre la cell suprieure gauche (eg: "A1")
;                  $SourceData          - les sries de donnes (eg: "$A$1:$A$30;$C$1:$C$30;$E$1:$E$30")
;										  soit sous la forme eg: "$A$1:$D$30"
;										  soit sous la forme eg: "A/B/C/D" correspondant aux colonnes utilises (ici, les 2 formes sont identiques)
;                  $ChartType           - type de graphique (eg: $xlLine)
;                  $Tracerpar           - faon dont les donnes sont traces $xlColumns ou $xlRows.
;                  $FormatGraphic       - [optional] Array[27] 27 lignes regroupant les formats. Default is "". Voir Remarks pour le dtail
;                  $FormatSave          - [optional] Format de sauvegarde "PNG" ou "PDF". Default is "".
;                  $PathSave            - [optional] Chemin de la sauvegarde. Default is "".
; Return values .: None
; Author ........: Walkson
; Modified ......:
; Remarks .......: Dtails du array $FormatGraphic. Les lignes sans intrt peuvent tre omises
;					Si les options sont utilises, $FormatGraphic[27] doit tre dclar
#cs
	la valeur Default laisse la configuration d'Excel choisir
	$FormatGraphic[0] = areacolor ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[1] = areafont ;nombre  ;taille Font
	$FormatGraphic[2] = areaTitle ;Texte
	$FormatGraphic[3] = areaTitle_font ;nombre  ;taille Font
	$FormatGraphic[4] = areaTitle_color ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[5] = areaBoder_style  ;XlLineStyle =>xlContinuous xlDot xlDash xlDashDot etc...
	$FormatGraphic[6] = areaBoder_color ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[7] = areaLine_weight ;nombre
	$FormatGraphic[8] = areaLine_style  ; MsoLineStyle =>msoLineThickThin msoLineSingle msoLineStyleMixed msoLineThickBetweenThin etc...
	------------------------------------------------------------------------------------------------
	;abscisses
	$FormatGraphic[9] = axeCategorie_font ;nombre  ;taille Font
	$FormatGraphic[10] = axeCategorie_color ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[11] = axeCategorie_linecolor ;nombre
	$FormatGraphic[12] = axeCategorie_style  ;XlLineStyle =>xlContinuous xlDot xlDash xlDashDot etc...
	$FormatGraphic[13] = axeCategorie_weight ;nombre
	------------------------------------------------------------------------------------------------
	;ordonnes
	$FormatGraphic[14] = axeValue_font ;nombre  ;taille Font
	$FormatGraphic[15] = axeValue_color ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[16] = axeValue_linecolor ;nombre  ;format ColorIndex de 1  56
	$FormatGraphic[17] = axeValue_style  ;XlLineStyle =>xlContinuous xlDot xlDash xlDashDot etc...
	$FormatGraphic[18] = axeValue_weight ;nombre
	-----------------------------------------------------------------------------------------------
	$FormatGraphic[19] = zonetracageBorder_style  ;XlLineStyle =>xlContinuous xlDot xlDash xlDashDot etc...
	$FormatGraphic[20] = zonetracageBorder_color ;nombre
	$FormatGraphic[21] = zonetracageBorder_weight ;nombre
	-------------------------------------------------------------------------------------------------
	$FormatGraphic[22] = courbes Default => ignor; True => mis en oeuvre
	$FormatGraphic[23] = courbes_lineweight si True ;nombre
	$FormatGraphic[24] = courbes_markersize si True ;nombre
	$FormatGraphic[25] = courbes_linestyle si True  ;XlLineStyle =>xlContinuous xlDot xlDash xlDashDot etc...
	-------------------------------------------------------------------------------------------------
	$FormatGraphic[26] = zonetracage_left ;nombre en point ;augmente marge gauche et recentre la zone tracage
	$FormatGraphic[27] = zonetracage_Top ;nombre en point ;augmente marge haute et recentre la zone tracage
#ce
; Related .......: constantGraphObjet2010.au3  ConstantsOfficeMso2013.au3
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func graphiqueExcel($oAppl, $SheetData, $Data, $SourceData, $ChartType, $Tracerpar, $FormatGraphic = "", $FormatSave = "", $PathSave = "")
	If Not IsObj($oAppl) Then Return SetError(1)
	If $SheetData = "" Then Return SetError(1)
	If $oAppl.Sheets($SheetData).Name = ""  Then Return SetError(1)
	If $Data = "" Then Return SetError(1)
	If $SourceData = "" Then Return SetError(1)
	If $ChartType = "" Then Return SetError(1)
	If $Tracerpar = "" Then Return SetError(1)
	If $FormatSave > "" Then
		If $PathSave = "" Then Return SetError(1)
		If StringRight($PathSave,3) <> $FormatSave Then Return SetError(1)
	EndIf

	$oAppl.ActiveWorkbook.Charts.Add
	$oAppl.ActiveChart.ChartType = $ChartType ;xlLineMarkers ;4;xlLine  57 ;xlBarClustered;xlBarStacked = 58
	$adB2 = $oAppl.Sheets($SheetData).Range($Data).End(-4121).Address(True, True) ;vers bas
	$nbL2 = $oAppl.Sheets($SheetData).Range($Data, $adB2).Rows.Count
	Local $aArray = StringRegExp($Data, '[0-9]?\d{1}', 3) ;les nb dans "A1:M30"
	If StringInStr($SourceData, "/") Then
		$split = StringSplit($SourceData, "/")
		Local $Range = ""
		Local $pointvirgule = ";"
		For $V = 1 To $split[0]
			If $V = $split[0] Then $pointvirgule = ""
			$Range &= $split[$V] & $aArray[0] & ":" & $split[$V] & $aArray[0] + $nbL2 - 1 & $pointvirgule
		Next
		$oAppl.ActiveChart.SetSourceData($oAppl.Sheets($SheetData).Range($Range), $Tracerpar)
		$oAppl.ActiveChart.Location(1) ;xlLocationAsNewSheet
		;ConsoleWrite($adB2 &">>"& $nbL2 &">>"& $Range & @CR)
	Else
		$oAppl.ActiveChart.SetSourceData($oAppl.Sheets($SheetData).Range($SourceData), $Tracerpar)
		$oAppl.ActiveChart.Location(1)
	EndIf
	;=====================================================
	With $oAppl.ActiveChart.PageSetup
		.LeftMargin = $oAppl.Application.InchesToPoints(0)
		.RightMargin = $oAppl.Application.InchesToPoints(0)
		.TopMargin = $oAppl.Application.InchesToPoints(0.1)
		.BottomMargin = $oAppl.Application.InchesToPoints(0.1)
		.HeaderMargin = $oAppl.Application.InchesToPoints(0)
		.FooterMargin = $oAppl.Application.InchesToPoints(0)
		.FitToPagesWide = 1
		.FitToPagesTall = 1
	EndWith
	;=====================================================
	Local $array[28]
	If Not IsArray($FormatGraphic) Then $FormatGraphic = $array
	For $i = 0 To 27
		If $FormatGraphic[$i] = "" Then
			$FormatGraphic[$i] = Default
			If $i = 2 Then $FormatGraphic[$i] = ""
		EndIf

	Next
	;_ArrayDisplay($FormatGraphic)
	;format graphique
	$oAppl.ActiveChart.SetElement($msoElementPrimaryCategoryGridLinesMajor)
	$oAppl.ActiveChart.ChartArea.Interior.ColorIndex = $FormatGraphic[0]
	$oAppl.ActiveChart.ChartArea.Font.Bold = True
	$oAppl.ActiveChart.ChartArea.Font.Size = $FormatGraphic[1]
	$oAppl.ActiveChart.HasTitle = True
	$oAppl.ActiveChart.ChartTitle.Text = $FormatGraphic[2]
	$oAppl.ActiveChart.ChartTitle.Font.Size = $FormatGraphic[3]
	$oAppl.ActiveChart.ChartTitle.Font.ColorIndex = $FormatGraphic[4]
	$oAppl.ActiveChart.ChartArea.Height = 567
	$oAppl.ActiveChart.ChartArea.Width = 813.65
	With $oAppl.ActiveChart.Axes(1)
		.TickLabels.Font.Size = $FormatGraphic[9]
		.TickLabels.Font.Bold = True
		.TickLabels.Font.colorindex = $FormatGraphic[10]
		If .HasMajorGridlines Then
			.MajorGridlines.Border.ColorIndex = $FormatGraphic[11] ;set color to blue
			.MajorGridlines.Border.LineStyle = $FormatGraphic[12] ;xlDot
			.MajorGridlines.Format.Line.Weight = $FormatGraphic[13]
		EndIf
	EndWith
	With $oAppl.ActiveChart.Axes(2)
		.TickLabels.Font.Size = $FormatGraphic[14]
		.TickLabels.Font.Bold = True
		.TickLabels.Font.colorindex = $FormatGraphic[15]
		If .HasMajorGridlines Then
			.MajorGridlines.Border.ColorIndex = $FormatGraphic[16] ;set color to blue
			.MajorGridlines.Border.LineStyle = $FormatGraphic[17] ;xlContinuous
			.MajorGridlines.Format.Line.Weight = $FormatGraphic[18]
		EndIf
	EndWith
	;xlCategory 1 L'axe affiche les abscisses.
	;xlSeriesAxis 3 L'axe affiche les sries de donnes.
	;xlValue 2 L'axe affiche les ordonnes.
	$SC = $oAppl.ActiveChart.SeriesCollection.Count
	$colorindex = 3 ;rouge
	With $oAppl.ActiveChart
		.ChartArea.Border.LineStyle = $FormatGraphic[5]
		.ChartArea.Border.ColorIndex = $FormatGraphic[6]
		.ChartArea.Format.Line.Weight = $FormatGraphic[7]
		.ChartArea.Format.Line.Style = $FormatGraphic[8] ;msoLineThickThin
		;zone tracage
		.PlotArea.Border.LineStyle = $FormatGraphic[19] ;xlContinuous
		.PlotArea.Border.ColorIndex = $FormatGraphic[20]
		.PlotArea.Format.Line.Weight = $FormatGraphic[21]
		;format des courbes
		If $FormatGraphic[22] <> Default Then
			For $y = 1 To $SC
				If $FormatGraphic[23] = Default And $FormatGraphic[24] = Default Then $colorindex =  -4105

				.SeriesCollection($y).Format.Line.Weight = $FormatGraphic[23]
				.SeriesCollection($y).Border.ColorIndex = $colorindex
				.SeriesCollection($y).MarkerStyle = $xlMarkerStyleAutomatic ;$xlMarkerStyleDiamond
				.SeriesCollection($y).MarkerSize = $FormatGraphic[24]
				.SeriesCollection($y).MarkerForegroundColorIndex = $colorindex
				.SeriesCollection($y).MarkerBackgroundColorIndex = $colorindex + 2
				.SeriesCollection($y).Border.LineStyle = $FormatGraphic[25]
				$colorindex += 1
			Next
		EndIf
		If $FormatGraphic[26] <> Default Then
			$_margeL = $FormatGraphic[26]
			.PlotArea.Left = .PlotArea.Left + $_margeL
			.PlotArea.Width = .PlotArea.Width - $_margeL
		EndIf
		If $FormatGraphic[27] <> Default Then
			$_margeT = $FormatGraphic[27]
			.PlotArea.Top = .PlotArea.Top + $_margeT
			.PlotArea.Height = .PlotArea.Height - $_margeT
		EndIf
	EndWith
	If $FormatSave = "PNG" Then
		$oAppl.ActiveChart.Export($PathSave)
	Else
		$oAppl.ActiveChart.ExportAsFixedFormat(0, $PathSave, 0)
	EndIf


EndFunc   ;==>graphiqueExcel